Attribute VB_Name = "basRadar"
' -------------------------------------------------------------------------
'
' basRadar(Radar.BAS)                                Ulrich Mller   3.5.98
'                                                    Dell XPS P90 VB4-16/32
'                                                             dto.      VB5
' Fischertechnik Radarturm : Public Variable
'      Public Routinen, Betriebsprogramme
'
' Die wesentlichen Betriebsprogramme sind :
'
' - Grundstellung   : Fahren des Radarturmes in Grundstellung
' - ScanAbwrts     : Scannen der Lichtwerte bei Schirm Abwrts
' - ScanAufwrts    : Scannen der Lichtwerte bei Schirm Aufwrts
' - StandardScan    : HauptProgramm, Endlosschleife
' - Turmincrement   : Drehen des Turmes um ein Increment mit Richtungsbest.
'
' -------------------------------------------------------------------------

Option Explicit

' --- Interface Konstanten ------

Public Const cComNr = 1                   ' Nr des ComPorts
Public Const cRLinks = 1                  ' Motor : nomineller Linkslauf
Public Const cRRechts = 2                 ' Motor : nomineller Rechtslauf
Public Const cRAus = 0                    ' Ausgang : Ausschalten
Public Const cREin = cRLinks              ' Ausgang : Einschalten
Public Const cReset = 8                   ' Reset-Eingang
Public Const cAEX = 0                     ' Analog-Eingang X

' --- Farbcodierungen ---

Public Const cFarbeAus = &H8000000F
Public Const cFarbeAusH = &HE0E0E0
Public Const cFarbeEin = &HFF00&
Public Const cFarbeFehler = &HFF8&
Public Const cFarbeEnde = &H80C0FF

' --- Turm -------------------------

Public Const cRTurmMotor = 1              ' --- M1
Public Const cRTurmRechts = cRRechts
Public Const cRTurmLinks = cRLinks
Public Const cRTurmEnde = 2               ' --- E2
Public Const cRTurmImpuls = 1             ' --- E1

' --- Schirm ------------------------

Public Const cRSchirmMotor = 2            ' --- M2
Public Const cRSchirmAuf = cRRechts
Public Const cRSchirmAb = cRLinks
Public Const cRSchirmEnde = 4             ' --- E4
Public Const cRSchirmImpuls = 3           ' --- E3

' --- Handbetrieb ------------------

Public Const cRHandbetrieb = 4            ' --- M4
Public Const cRHandEin = cRAus
Public Const cRHandAus = cREin

' --- RadarAuge --------------------

Public Const cRRadarAuge = cAEX
Public fKalib!                      ' Kalibrierungsfaktor

' --- Public Variable --------------

Public ft As frmFishFace            ' Kurzschreibweise zum Ansprechen
                                    ' von Funktionen des FishFace
Public mf As frmRadarMain           ' Kurzschreibweise fr RadarMain
Public ProgrammNr%                  ' Nr des akt. laufenden Programms
Public ProgrammBeenden As Boolean   ' Anforderung Programmende

' --- Modul globale Variable -------

Private TurmPosition%               ' Turmposition in Anzahl Impulsen
                                    ' Position Rechts = 0
Private SchirmPosition%             ' Schirmposition in Anzahl Impulsen
                                    ' Position Oben = 0
Private Turm350%                    ' Anzahl Impulse fr eine 350 Drehung
Private TurmIncr%                   ' Anzahl Impulse fr ein Increment
Private Schirm45%                   ' Anzahl Impulse fr eine 45 Senkung
                                    
Private Sub Grundstellung()

' --- Fahren des Radarturmes in Grundstellung ---
'     Turm : rechts, Endschalter, Schirmauf
  
  If Not ft.GetInput(cRTurmEnde) Then ft.SetMotor cRTurmMotor, cRTurmRechts
  If Not ft.GetInput(cRSchirmEnde) Then ft.SetMotor cRSchirmMotor, cRSchirmAuf
  
  Do
    If ft.GetInput(cRTurmEnde) Then ft.SetMotor cRTurmMotor, cRAus
    If ft.GetInput(cRSchirmEnde) Then ft.SetMotor cRSchirmMotor, cRAus
  Loop Until ft.GetInput(cRTurmEnde) And ft.GetInput(cRSchirmEnde)
  
  ft.SetMotor cRTurmMotor, cRAus
  ft.SetMotor cRSchirmMotor, cRAus
  TurmPosition = 0
  SchirmPosition = 0
  
End Sub

Private Sub RadarWert()

' --- Anzeige des aktuellen Wertes von cRRadarAuge auf picRadar ---

Static Helligkeit!

  Helligkeit = ft.GetAnalog(cRRadarAuge)
  If Helligkeit = 0 Then Helligkeit = 1024
  Helligkeit = 1025 - Helligkeit            ' --- Heller : grerer Wert
  Helligkeit = Helligkeit * fKalib + 79     ' --- Grundhelligkeit : 79
                                            ' --- Scalieren auf Restbereich
  mf!picRadar.Line (TurmPosition, SchirmPosition)-Step(10, 1), RGB(0, Helligkeit, 0), BF
  
End Sub


Private Sub ScanAbwrts(Schritte%)

' --- Scannen der Lichtwerte bei Schirm Abwrts ---

Dim i%

  ft.SetMotor cRSchirmMotor, cRSchirmAb
  RadarWert
  
  For i = 1 To Schirm45 Step Schritte
    ft.WaitForChange cRSchirmImpuls, Schritte
    mf!picRadarY.Line (2, SchirmPosition)-Step(6, 1), cFarbeAusH, BF
    SchirmPosition = SchirmPosition + Schritte
    RadarWert
    mf!picRadarY.Line (2, SchirmPosition)-Step(6, 1), cFarbeEin, BF
  Next i
  
  ft.SetMotor cRSchirmMotor, cRAus
  
End Sub


Private Sub ScanAufwrts(Schritte%)

' --- Scannen der Lichtwerte bei Schirm Aufwrts ---

  ft.SetMotor cRSchirmMotor, cRSchirmAuf
  RadarWert
  
  Do
    ft.WaitForChange cRSchirmImpuls, Schritte
    mf!picRadarY.Line (2, SchirmPosition)-Step(6, 1), cFarbeAusH, BF
    SchirmPosition = SchirmPosition - Schritte
    RadarWert
    mf!picRadarY.Line (2, SchirmPosition)-Step(6, 1), cFarbeEin, BF
  Loop Until ft.GetInput(cRSchirmEnde)
  
  ft.SetMotor cRSchirmMotor, cRAus
  SchirmPosition = 0
  
End Sub


Public Sub StandardScan()

' --- Scan der Helligkeitswerte der Umgebung und Anzeige in picRadar ---
'     Schleife, Ende durch ProgrammBeenden = True aus frmRadarMain!cmdAction

  mf!lblStatus = "StandardScan : auf Grundstellung"

' --- Scanwerte ---

  Turm350 = 330
  TurmIncr = 15
  Schirm45 = 44
  
' --- Beschriftung Form, Init pic-Bereiche ---

  mf!lblRadarX = Turm350
  mf!lblRadarY = Schirm45
  mf!picRadar.Scale (0, 0)-(Turm350 + 15, Schirm45)
  mf!picRadar.Cls
  mf!picRadarX.Scale (0, 0)-(Turm350 + 15, 10)
  mf!picRadarX.Cls
  mf!picRadarY.Scale (0, 0)-(10, Schirm45)
  mf!picRadarY.Cls
  
' --- Anfahren der Grundstellung ---

  Grundstellung
    
' --- Scan-Schleife, Abbruch durch Button cmdAction ---

  mf!lblStatus = "StandardScan luft"
  
  Do
    ScanAbwrts 2
    TurmIncrement
    ScanAufwrts 2
    TurmIncrement
  Loop Until ProgrammBeenden
  
  ft.ClearMotors
  mf!lblStatus = "StandardScan beendet"
  mf!lblStatus.BackColor = cFarbeEnde
  
End Sub

Private Sub TurmIncrement()

' --- Drehen des Turms um TurmIncr, die Drehrichtung wird selbstndig
'     bestimmt, vor dem ersten Aufruf Position am rechten Endschalter

Static DrehRichtung%, PosAdd%

' --- Richtungsbestimmung ---

  If ft.GetInput(cRTurmEnde) Then
    ft.SetMotor cRTurmMotor, cRTurmLinks
    ft.WaitForLow cRTurmImpuls            ' um den Endschalter zu lsen
    TurmPosition = 0
    DrehRichtung = cRTurmLinks
    PosAdd = TurmIncr
    mf!picRadarX.Line (TurmPosition, 2)-Step(10, 6), cFarbeEin, BF
  End If
  If TurmPosition >= Turm350 Then
    DrehRichtung = cRTurmRechts
    PosAdd = -TurmIncr
  End If
  
' --- Drehen um das Increment (TurmIncr) --------

  ft.SetMotor cRTurmMotor, DrehRichtung
  ft.WaitForChange cRTurmImpuls, TurmIncr, cRTurmEnde
  ft.SetMotor cRTurmMotor, cRAus
  mf!picRadarX.Line (TurmPosition, 2)-Step(10, 6), cFarbeAusH, BF
  TurmPosition = TurmPosition + PosAdd
  mf!picRadarX.Line (TurmPosition, 2)-Step(10, 6), cFarbeEin, BF
  
End Sub


